@@ -35,7 +35,7 @@ EOF
     checkCompileAndRunTestProgram ../example.ncd.xml "$cmp" demo
 }
 
-testCompileTestProg() {
+testCompileTestProg2() {
     cmp=$(cat <<EOF
 Enum value number 0 has name "A" and value 0
 Enum value number 1 has name "B" and value 1
@@ -47,4 +47,16 @@ EOF
     checkCompileAndRunTestProgram ../example.ncd.xml "$cmp" demo mainscript2.js
 }
 
+testCompileTestProg3() {
+    cmp=$(cat <<EOF
+Enum value number 0 has name "A" and value 0
+Enum value number 1 has name "B" and value 1
+Enum value number 2 has name "C" and value 12
+Enum value number 3 has name "D" and value 13
+Enum value number 4 has name "E" and value 4
+EOF
+       )
+    checkCompileAndRunTestProgram ../example.ncd.xml "$cmp" demo mainscript3.js
+}
+
 . shunit2
